==> kreetingkard-0.4.2.tar.gz: kreetingkard/src/kkpropertyitemtext.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKPROPERTYITEMTEXT_H
#define KKPROPERTYITEMTEXT_H

#include <ktextedit.h>

#include "kkpropertyitembase.h"

class KKPropertyItemText : public KKPropertyItemBase
{
	Q_OBJECT
public:
	KKPropertyItemText( KKProperty* parent, QString text );

	~KKPropertyItemText();

public slots:
	void reset();
	void start();
	void accept();

private:
	KTextEdit* txtEdit;
};

#endif //KKPROPERTYITEMTEXT_H

==> kreetingkard-0.4.3.tar.gz: kreetingkard/src/kkpropertyitemtext.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKPROPERTYITEMTEXT_H
#define KKPROPERTYITEMTEXT_H

#include <ktextedit.h>

#include "kkpropertyitembase.h"

class KKPropertyItemText : public KKPropertyItemBase
{
	Q_OBJECT
public:
	KKPropertyItemText( KKProperty* parent, const QString &text );

	~KKPropertyItemText();

public slots:
	void reset();
	void start();
	void accept();

private:
	KTextEdit* txtEdit;
};

#endif //KKPROPERTYITEMTEXT_H
